@@ -1,21 +1,23 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.Rendering.OpenGL.Raw.ARB.HalfFloatPixel
--- Copyright   :  (c) Sven Panne 2009
--- License     :  BSD-style (see the file LICENSE)
+-- Copyright   :  (c) Sven Panne 2015
+-- License     :  BSD3
 --
--- Maintainer  :  sven.panne@aedion.de
+-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
 -- Stability   :  stable
 -- Portability :  portable
 --
--- All tokens from the ARB_half_float_pixel extension, see
--- <http://www.opengl.org/registry/specs/ARB/half_float_pixel.txt>.
+-- The <https://www.opengl.org/registry/specs/ARB/half_float_pixel.txt ARB_half_float_pixel> extension.
 --
 --------------------------------------------------------------------------------
 
 module Graphics.Rendering.OpenGL.Raw.ARB.HalfFloatPixel (
-   -- * Tokens
-   gl_HALF_FLOAT
+  -- * Types
+  GLhalfARB,
+  -- * Enums
+  gl_HALF_FLOAT_ARB
 ) where
 
-import Graphics.Rendering.OpenGL.Raw.Core32
+import Graphics.Rendering.OpenGL.Raw.Types
+import Graphics.Rendering.OpenGL.Raw.Tokens
