@@ -1,22 +1,21 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.Rendering.OpenGL.Raw.ARB.PointSprite
--- Copyright   :  (c) Sven Panne 2009
--- License     :  BSD-style (see the file LICENSE)
+-- Copyright   :  (c) Sven Panne 2015
+-- License     :  BSD3
 --
--- Maintainer  :  sven.panne@aedion.de
+-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
 -- Stability   :  stable
 -- Portability :  portable
 --
--- All tokens from the ARB_point_sprite extension, see
--- <http://www.opengl.org/registry/specs/ARB/point_sprite.txt>.
+-- The <https://www.opengl.org/registry/specs/ARB/point_sprite.txt ARB_point_sprite> extension.
 --
 --------------------------------------------------------------------------------
 
 module Graphics.Rendering.OpenGL.Raw.ARB.PointSprite (
-   -- * Tokens
-   gl_POINT_SPRITE,
-   gl_COORD_REPLACE
+  -- * Enums
+  gl_COORD_REPLACE_ARB,
+  gl_POINT_SPRITE_ARB
 ) where
 
-import Graphics.Rendering.OpenGL.Raw.ARB.Compatibility
+import Graphics.Rendering.OpenGL.Raw.Tokens
