@@ -1,21 +1,20 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.Rendering.OpenGL.Raw.ARB.ShadingLanguage100
--- Copyright   :  (c) Sven Panne 2009
--- License     :  BSD-style (see the file LICENSE)
+-- Copyright   :  (c) Sven Panne 2015
+-- License     :  BSD3
 --
--- Maintainer  :  sven.panne@aedion.de
+-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
 -- Stability   :  stable
 -- Portability :  portable
 --
--- All tokens from the ARB_shading_language_100 extension, see
--- <http://www.opengl.org/registry/specs/ARB/shading_language_100.txt>.
+-- The <https://www.opengl.org/registry/specs/ARB/shading_language_100.txt ARB_shading_language_100> extension.
 --
 --------------------------------------------------------------------------------
 
 module Graphics.Rendering.OpenGL.Raw.ARB.ShadingLanguage100 (
-   -- * Tokens
-   gl_SHADING_LANGUAGE_VERSION
+  -- * Enums
+  gl_SHADING_LANGUAGE_VERSION_ARB
 ) where
 
-import Graphics.Rendering.OpenGL.Raw.Core32
+import Graphics.Rendering.OpenGL.Raw.Tokens
