@@ -1,21 +1,20 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.Rendering.OpenGL.Raw.NV.DepthClamp
--- Copyright   :  (c) Sven Panne 2009
--- License     :  BSD-style (see the file LICENSE)
+-- Copyright   :  (c) Sven Panne 2015
+-- License     :  BSD3
 --
--- Maintainer  :  sven.panne@aedion.de
+-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
 -- Stability   :  stable
 -- Portability :  portable
 --
--- All tokens from the NV_depth_clamp extension, see
--- <http://www.opengl.org/registry/specs/NV/depth_clamp.txt>.
+-- The <https://www.opengl.org/registry/specs/NV/depth_clamp.txt NV_depth_clamp> extension.
 --
 --------------------------------------------------------------------------------
 
 module Graphics.Rendering.OpenGL.Raw.NV.DepthClamp (
-   -- * Tokens
-   gl_DEPTH_CLAMP
+  -- * Enums
+  gl_DEPTH_CLAMP_NV
 ) where
 
-import Graphics.Rendering.OpenGL.Raw.ARB.DepthClamp
+import Graphics.Rendering.OpenGL.Raw.Tokens
