@@ -1,22 +1,21 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.Rendering.OpenGL.Raw.NV.TexgenReflection
--- Copyright   :  (c) Sven Panne 2009
--- License     :  BSD-style (see the file LICENSE)
+-- Copyright   :  (c) Sven Panne 2015
+-- License     :  BSD3
 --
--- Maintainer  :  sven.panne@aedion.de
+-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
 -- Stability   :  stable
 -- Portability :  portable
 --
--- All tokens from the NV_texgen_reflection, see
--- <http://www.opengl.org/registry/specs/NV/texgen_reflection.txt>.
+-- The <https://www.opengl.org/registry/specs/NV/texgen_reflection.txt NV_texgen_reflection> extension.
 --
 --------------------------------------------------------------------------------
 
 module Graphics.Rendering.OpenGL.Raw.NV.TexgenReflection (
-   -- * Tokens
-   gl_NORMAL_MAP,
-   gl_REFLECTION_MAP
+  -- * Enums
+  gl_NORMAL_MAP_NV,
+  gl_REFLECTION_MAP_NV
 ) where
 
-import Graphics.Rendering.OpenGL.Raw.ARB.Compatibility
+import Graphics.Rendering.OpenGL.Raw.Tokens
